/* 	Copyright (c) 1993 NeXT Computer, Inc.  All rights reserved. 
 *
 * IOTokenRing.h - TokenRing device-independent superclass
 *
 *	The TokenRing superclass contains the device-independent functions
 *	that are common to most token-ring drivers.  The hardware-specific
 *	driver should be a subclass of IOTokenRing.
 *
 * HISTORY
 * 25-Jan-93 
 *	created
 *      
 */

#ifdef KERNEL

#import <driverkit/IODirectDevice.h>
#import <driverkit/IONetwork.h>
#import <kernserv/ns_timer.h>
#import <net/tokendefs.h>


@interface IOTokenRing:IODirectDevice<IONetworkDeviceMethods>
{
@private

    /* 
     * Interface flags 
     */
	
    struct _trFlags {
	unsigned int        _isRunning:1;	
	unsigned int        _isEarlyTokenEnabled:1;
	unsigned int        _shouldAutoRecover:1;
	unsigned int        _shouldAttachIP:1;	
	unsigned int        _shouldAttachNullSap:1;
	unsigned int        _doesIPSourceRouting:1;
	unsigned int        RESERVED:10;
    }	_flags;

    /* 
     * Interface parameters 
     */
	
    unsigned 	_ringSpeed;	
    unsigned	_ipTokenPriority;
    unsigned	_ipMtu;		
    unsigned	_maxInfoFieldSize;
    
    /*
     * Hardware addresses
     */
	
    token_addr_t	_nodeAddress; 	
    token_addr_t	_groupAddress;	
    token_addr_t 	_functionalAddress;
	    
    /*
     * Other instance variables
     */

    IONetwork	*_netif;
    id		_driverCmd;		 
    ns_time_t 	_absTimeout;	
    id		_hwLock;
    int		_IOTokenRing_reserved[4];
}

- initFromDeviceDescription:(IODeviceDescription *)devDesc;
- free;

- (BOOL)isRunning;
- (void)setRunning:(BOOL)running;

- (unsigned int)relativeTimeout;
- (void)setRelativeTimeout:(unsigned int)timeout;
- (void)clearTimeout;

- (BOOL)earlyTokenEnabled;		
- (BOOL)shouldAutoRecover;		
- (unsigned)ringSpeed;			

- (unsigned)maxInfoFieldSize;		
- (void)setMaxInfoFieldSize:(unsigned)size;

/*
 * Hardware Addresses
 */

- (token_addr_t)nodeAddress;			

@end

@interface IOTokenRing(DriverInterface)

- (BOOL)resetAndEnable:(BOOL)enable;
- (IONetwork *)attachToNetworkWithAddress:(token_addr_t)addrs;

/*
 * NOTE:  Use of the transmit: method may be undesirable in cases
 *        where it forces buffer copying, or precludes a subclass
 *	  buffer management scheme.  In those cases it is preferable
 *	  to override the outputPacket:address: method (and perhaps the 
 *	  allocateNetbuf method).  If the outputPacket:address: method is 
 *	  overridden, then no transmit method is required.	 
 */
 
- (void)transmit:(netbuf_t)pkt; 


@end

#endif
