/*
IXAttributeParser.h
Copyright 1991, NeXT Computer, Inc.
*/

#import	<objc/Object.h>
#import	<objc/hashtable.h>
#import	<dpsclient/dpsclient.h>

#import	"protocols.h"

@class List, IXAttributeBinder, IXFileConverter, IXWeightingDomain;



extern NXAtom	IXDefaultAttribute;
extern NXAtom	IXContentAttribute;





extern NXAtom	IXAttributeReaderPboardType;
extern NXAtom	IXFileDescriptionPboardType;







typedef enum {
    IX_NoWeighting = 0, 
    IX_AbsoluteWeighting, IX_FrequencyWeighting, IX_PeculiarityWeighting 
} IXWeightingType;

@interface IXAttributeParser: Object <IXAttributeBinding>
{
    BOOL		_tokenUniquing;
    NXHashTable		*_sourceTypes;
    id			_attributeBinder;
    id			_fileConverter;
    List		*_attributeMapping;
    List		*_attributeReaders;
    IXWeightingType	_weightingType;
    IXWeightingDomain	*_weightingDomain;
    unsigned		_minimumWeight;
    unsigned		_percentPassed;
}



+ (DPSPortProc)getFilterHandler:(port_t)filterPort;




- getAttributeReaders:(List *)aList;
- setAttributeReaders:(List *)aList;

- (BOOL)understandsType:(const char *)type;
- addSourceType:(const char *)type;
- removeSourceType:(const char *)type;

@end

@interface IXAttributeParser(Parsing)

- reset;


- parseFile:(const char *)filename ofType:(const char *)type;
- parseStream:(NXStream *)stream ofType:(const char *)type;





- (NXStream *)analyzeFile:(const char *)filename ofType:(const char *)type;
- (NXStream *)analyzeStream:(NXStream *)stream ofType:(const char *)type;

@end

@interface IXAttributeParser(Configuration)

- (unsigned)minimumWeight;
- setMinimumWeight:(unsigned)aMinimum;

- (unsigned)percentPassed;
- setPercentPassed:(unsigned)aPercent;

- (IXWeightingDomain *)weightingDomain;
- setWeightingDomain:(IXWeightingDomain *)aDomain;

- (IXWeightingType)weightingType;
- setWeightingType:(IXWeightingType)type;

- (IXFileConverter *)fileConverter;
- setFileConverter:(IXFileConverter *)aConverter;

@end

