/*
IXFileFinder.h
Copyright 1991, NeXT Computer, Inc.
*/

#import <objc/hashtable.h>
#import	<machkit/reference.h>

#import	"IXPostingList.h"

@class IXBTree, IXFileFinder, IXFileRecord;

typedef struct 			{
    unsigned			recordNumber;
    unsigned			dateModified;
} IXFileRegistration;

@protocol IXFileFinderQueryAndUpdate

- (const char *)rootPath;



- recordManager;

- (char *)attributeNames;

- clean;
- reset;


- updateIndexAtPath:(const char *)path forSender:aSender;

- (BOOL)isUpdating;
- resumeUpdating;
- suspendUpdating;

- stopQueryForSender:aSender;
- (IXPostingList *)performQuery:(const char *)query 
    atPath:(const char *)path forSender:aSender;




- (IXBTree *)registry;

@end

@interface Object(IXFileFinderSender)


- fileFinder:(IXFileFinder *)aFinder 
    didFindFiles:(IXPostingList *)aList;




- (BOOL)fileFinder:(IXFileFinder *)aFinder 
    willTryPath:(const char *)filename;




- fileFinder:(IXFileFinder *)aFinder 
    willAddFile:(IXFileRecord *)anObject;





- fileFinder:(IXFileFinder *)aFinder 
    didAddFile:(IXFileRecord *)anObject;


- fileFinder:(IXFileFinder *)aFinder 
    didFindFile:(IXFileRecord *)anObject;

@end

@protocol IXFinderControl


- fileFinder:(IXFileFinder *)aFinder willEnumerate:(char *)filename;


- (IXPostingList *)fileFinder:(IXFileFinder *)aFinder 
    didPerform:(char *)query atPath:(char *)path forSender:aSender;

@end

@protocol IXFileFinderConfiguration




- getAttributeParsers:(List *)aList;
- setAttributeParsers:(List *)aList;



- (char *)ignoredTypes;
- setIgnoredTypes:(const char *)types;



- readIgnoredTypes:(NXStream *)aStream;
- writeIgnoredTypes:(NXStream *)aStream;



- readIgnoredTypesFromFile:(const char *)filename;
- writeIgnoredTypesToFile:(const char *)filename;



- (char *)ignoredNames;
- setIgnoredNames:(const char *)names;



- readIgnoredNames:(NXStream *)aStream;
- writeIgnoredNames:(NXStream *)aStream;



- readIgnoredNamesFromFile:(const char *)filename;
- writeIgnoredNamesToFile:(const char *)filename;




- (BOOL)considersHiddenFiles;
- setConsidersHiddenFiles:(BOOL)flag;

- (BOOL)crossesDeviceChanges;
- setCrossesDeviceChanges:(BOOL)flag;

- (BOOL)followsSymbolicLinks;
- setFollowsSymbolicLinks:(BOOL)flag;

- (BOOL)generatesDescriptions;
- setGeneratesDescriptions:(BOOL)flag;

- (BOOL)updatesAutomatically;
- setUpdatesAutomatically:(BOOL)flag;

- (BOOL)scansForModifiedFiles;
- setScansForModifiedFiles:(BOOL)flag;

- (BOOL)removesAutomatically;
- setRemovesAutomatically:(BOOL)aBoolean;

- (unsigned)commitDelay;
- setCommitDelay:(unsigned)seconds;

- (id <IXFinderControl>)finderControl;
- setFinderControl:(id <IXFinderControl>)anObject;

@end



@interface IXFileFinder: Object <NXReference, IXNameAndFileAccess, IXFileFinderQueryAndUpdate, IXFileFinderConfiguration, IXAttributeBinding>
{
    struct FinderRecord	*_finderRecord;
    unsigned		references;
    List		*attributeParsers;
    id			recordManager;
    NXHashTable		*ignoredNames;
    NXHashTable		*ignoredTypes;
    char		*rootPath;
    unsigned		commitDelay;
    struct		{
	unsigned	crossesDeviceChanges:1;
	unsigned	followsSymbolicLinks:1;
	unsigned	generatesDescriptions:1;
	unsigned	updatesAutomatically:1;
	unsigned	scansForModifiedFiles:1;
	unsigned	removesAutomatically:1;
	unsigned	considersHiddenFiles:1;
    } 			booleanOptions;
}


- (IXStore *)store;









- initInStore:(IXStore *)aStore 
    atPath:(const char *)path;
- initFromBlock:(unsigned)block inStore:(IXStore *)aStore 
    atPath:(const char *)path;

- initWithName:(const char *)name inFile:(const char *)filename 
    atPath:(const char *)path;
- initFromName:(const char *)aName inFile:(const char *)filename 
    forWriting:(BOOL)flag atPath:(const char *)path;

@end

#ifdef KANJI

#define IX_NOTDEF_ENCODING	0
#define IX_NEXTSTEP_ENCODING	1
#define IX_NJE_ENCODING	2

@interface IXFileFinder(QueryEncoding)

- (unsigned)queryEncoding;
- setQueryEncoding:(unsigned)encoding;

@end

#endif
