/*
IXRecordManager.h
Copyright 1991, NeXT Computer, Inc.
*/

#import	<btree/IXPostingCursor.h>
#import	<mach/cthreads.h>

#import	"IXAttributeParser.h"
#import	"IXPostingList.h"

@class IXStore, IXAttribute, IXBTreeCursor;

extern IXAttributeParser *IXDefaultAttributeParser();












@interface IXRecordManager: Object 
<IXNameAndFileAccess, IXRecordWriting, IXTransientAccess, IXTransientMessaging, IXAttributeBinding>
{
    struct mutex		_mutexLock;
    id				_storeDirectory;
    id				_dataRepository;
    BOOL			_freeStore;
    unsigned			_handle;
    char			*_handleName;
    IXStore			*_store;
    struct _NXMapTable		*_attributeNames;
    struct _NXMapTable		*_attributeLists;
    struct _NXMapTable		*_privateCursors;
    IXBTreeCursor		*_attributeBTree;
    IXBTreeCursor		*_attributeTable;
    id				_delegate;
}


- (IXStore *)store;



- removeAttributeNamed:(const char *)name;
- addAttributeNamed:(const char *)name forSelector:(SEL)selector;
- (BOOL)hasAttributeNamed:(const char *)name;

- (unsigned)attributeCount;

- (char *)attributeNames;
- (IXPostingCursor *)cursorForAttributeNamed:(const char *)name;
- (SEL)selectorForAttributeNamed:(const char *)name;

- (char *)classNames;
- (char *)attributeNamesForClass:aClass;

- clean;
- discardRecord:(unsigned)record;
- reclaimRecord:(unsigned)record;

- (unsigned)capacity;
- (IXPostingList *)contents;

- (IXPostingList *)discards;
- (IXPostingList *)removals;

- (IXPostingList *)recordsForClass:aClass;




- setTargetClass:aClass forAttributeNamed:(const char *)name;
- getTargetName:(const char **)target andVersion:(unsigned *)version 
    forAttributeNamed:(const char *)name;



- getDescription:(char **)aDescription forAttributeNamed:(const char *)name;
- setDescription:(const char *)aDescription 
    forAttributeNamed:(const char *)name;




- (const char *)comparisonFormatForAttributeNamed:(const char *)name;
- setComparisonFormat:(const char *)aFormat 
    forAttributeNamed:(const char *)name;




- getComparator:(IXComparator **)comparator andContext:(const void **)context 
    forAttributeNamed:(const char *)name;
- setComparator:(IXComparator *)comparator andContext:(const void *)context 
    forAttributeNamed:(const char *)name;




- (IXAttributeParser *)parserForAttributeNamed:(const char *)name;
- setParser:(IXAttributeParser *)aParser 
    forAttributeNamed:(const char *)name;


- setDelegate:anObject;
- delegate;





- (BOOL)getValue:(void **)value andLength:(unsigned *)length 
    ofBlob:(const char *)name forRecord:(unsigned)record;
- (BOOL)setValue:(const void *)value andLength:(unsigned)length 
    ofBlob:(const char *)name forRecord:(unsigned)record;




- addAttribute:(IXAttribute *)anAttribute;
- (const IXAttribute *)attributeNamed:(const char *)name;
- removeAttribute:(IXAttribute *)anAttribute;

@end



@interface Object(IXRecordManagerDelegate)


- source:aSource didRead:anObject forRecord:(unsigned)record;


- source:aSource didAdd:anObject forRecord:(unsigned)record;


- source:aSource didRemove:anObject forRecord:(unsigned)record;

@end

