/*  NXConnection.h
    Copyright 1992, NeXT, Inc.
*/

#import <stdlib.h>
#import <stdarg.h>
#import <objc/hashtable.h>
#import <objc/Protocol.h>
#import <objc/List.h>
#import <machkit/NXLock.h>
#import <remote/transport.h>
#import <machkit/NXInvalidationNotifier.h>

@class NXProxy;
@class NXPort;

/*****************  NXConnection    **************************/

/* A connection object is a bookkeeper for objects vended or received over a particular portal (channel) resource.  It may be shared by multiple threads. */

@interface NXConnection: NXInvalidationNotifier <NXSenderIsInvalid> {
    id  delegate;
@private
    id  inPortal;  
    void *inMachPort;
    id  outPortal; 
    void *outMachPort;
    id                  rootObject;
    unsigned            msgcount;  
    void                *localProxies;
    void                *remoteProxies;
    int                 inTimeout;
    int                 outTimeout;
    NXZone              *zone;
    id                  bufferClass;
}

+ (NXProxy *) connectToName:(const char *)n;
+ (NXProxy *) connectToName:(const char *)n onHost:(const char *)h;
+ (NXProxy *) connectToPort:(NXPort *)p;   
+ (NXProxy *) connectToPort:(NXPort *)aPort withInPort:(NXPort *)inPort;

+ (NXProxy *) connectToName:(const char *)n fromZone:(NXZone *) z;
+ (NXProxy *) connectToName:(const char *)n onHost:(const char *)h fromZone:(NXZone *) z;
+ (NXProxy *) connectToPort:(NXPort *)p fromZone:(NXZone *) z;
+ (NXProxy *) connectToPort:(NXPort *)aPort withInPort:(NXPort *)inPort fromZone:(NXZone *) z;

+ registerRoot:anObject;   
+ registerRoot:anObject withName:(const char *)n;  

+ registerRoot:anObject fromZone:(NXZone *) z;
+ registerRoot:anObject withName:(const char *)n fromZone:(NXZone *) z;

+ removeObject:anObject;
+ unregisterForInvalidationNotification:anObject;

+ (int)messagesReceived;

+ connections:(List *) l;  

+ setDefaultTimeout:(int) t;
+ (int) defaultTimeout;

+ setDefaultZone: (NXZone *) zone;
+ (NXZone *) defaultZone;



- setDelegate:anObject;
- delegate;

- setRoot:anObject;

- setInTimeout:(int) t;
- setOutTimeout:(int) t;
- (int) inTimeout;
- (int) outTimeout;

- (NXPort *) inPort;
- (NXPort *) outPort;

- rootObject;

- newRemote:(unsigned)name withProtocol:(Protocol *)p;

- (List *)remoteObjects;   
- (List *)localObjects;    

- getLocal:anId;       

- run;                 
- runWithTimeout:(int) t;
- runInNewThread;      

- free;
@end
 


@interface NXConnection (NXAppKitServer) 
- runFromAppKit;   
@end




#define NX_CONNECTION_DEFAULT_TIMEOUT   15000
