/* transport.h
 * encoding/decoding protocols for DistributedObjects
 * Copyright 1992, NeXT Computer, Inc.
 */

#import <objc/Object.h>
#import <mach/port.h>

/* these are the general encoding/decoding protocols implemented by all objective-C message buffering/delivery classes */

/* The general scheme is that Proxys will encode a method and its arguments onto a portal, and/or decode requests or replies from a portal.  The encoding/decoding protocol allows for potentially different implementations of portals, such as an in memory queue or a TCP channel or a System V STREAMS version... or whatever your favorite connection paradigm is.  Note that the treatment of MACH memory and MACH ports would need to be emulated very closely in any underlying implementation. */

@protocol NXEncoding

- encodeData:(void *)data ofType:(const char *)type;


- encodeBytes:(const void *)bytes count:(int)count;
- encodeVM:(const void *)bytes count:(int)count;
- encodeMachPort:(port_t)port;
- encodeObject:anObject;   
- encodeObjectBycopy:anObject; 

@end

@protocol NXDecoding

- decodeData:(void *)d ofType:(const char *)t;


- decodeBytes:(void *)bytes count:(int)count;
- decodeVM:(void **)bytes count:(int *)count;
- decodeMachPort:(port_t *)pp;
- (id) decodeObject;                   
@end

/* Objects that encode themselves "on the wire" need to implement the following methods */

@class NXConnection;

@protocol NXTransport









- encodeRemotelyFor:(NXConnection *)connection freeAfterEncoding:(BOOL *)flagp isBycopy:(BOOL)isBycopy;


- encodeUsing:(id <NXEncoding>)portal;

- decodeUsing:(id <NXDecoding>)portal;
@end


/* Object provides an implementation that creates NXProxies on the other side */

@interface Object (Object_MakeRemote)
- encodeRemotelyFor:(NXConnection *)connection freeAfterEncoding:(BOOL *)flagp isBycopy:(BOOL)isBycopy;
@end



