/*
 *	snddriver_client.h
 *	Copyright 1990 NeXT, Inc.
 *
 *	This file gets #import'ed by sounddriver.h.
 */
 
kern_return_t snddriver_get_device_parms (
	port_t		device_port,	
	boolean_t	*speaker,	
	boolean_t	*lowpass,	
	boolean_t	*zerofill);

kern_return_t snddriver_set_device_parms (
	port_t		device_port,	
	boolean_t	speaker,	
	boolean_t	lowpass,	
	boolean_t	zerofill);

/* new in 2.0 */
kern_return_t snddriver_set_ramp (
	port_t		device_port,	
	int		rampflags);	

kern_return_t snddriver_get_volume (
	port_t		device_port,	
	int		*left_chan,	
	int		*right_chan);

kern_return_t snddriver_set_volume (
	port_t		device_port,	
	int		left_chan,	
	int		right_chan);

kern_return_t snddriver_set_dsp_owner_port (
	port_t		device_port,	
	port_t		owner_port,	
	port_t		*neg_port);

kern_return_t snddriver_set_sndin_owner_port (
	port_t		device_port,	
	port_t		owner_port,	
	port_t		*neg_port);

kern_return_t snddriver_set_sndout_owner_port (
	port_t		device_port,	
	port_t		owner_port,	
	port_t		*neg_port);

kern_return_t snddriver_get_dsp_cmd_port (
	port_t		device_port,	
	port_t		owner_port,	
	port_t		*cmd_port);

kern_return_t snddriver_dspcmd_req_msg (
	port_t		cmd_port,	
	port_t		reply_port);

kern_return_t snddriver_dspcmd_req_err (
	port_t		cmd_port,	
	port_t		reply_port);

kern_return_t snddriver_dspcmd_req_condition (
	port_t		cmd_port,	
	u_int		mask,		
	u_int		flags,		
	int		priority,	
	port_t		reply_port);

kern_return_t snddriver_dsp_set_flags (
	port_t		cmd_port,	
	u_int		mask,		
	u_int		flags,		
	int		priority);

kern_return_t snddriver_dsp_host_cmd (
	port_t		cmd_port,	
	u_int		host_command,	
	int		priority);

/* New for 2.0 */
kern_return_t snddriver_dsp_read_data (
	port_t		cmd_port,	
	void		**data,		
	int		count,		
	int		data_size,	
	int		priority);	

/* New for 2.0 */
kern_return_t snddriver_dsp_read_messages (
	port_t		cmd_port,	
	void		*data,		
	int		*count,		
	int		data_size,	
	int		priority);	

kern_return_t snddriver_dsp_read (
	port_t		cmd_port,	
	void		*data,		
	int		*count,		
	int		data_size,	
	int		priority);
/* Calls read_messages if DSPMSG, DSPERR, or C_DMA protocol, else read_data */

kern_return_t snddriver_dsp_write (
	port_t		cmd_port,	
	void		*data,		
	int		count,		
	int		data_size,	
	int		priority);

kern_return_t snddriver_dsp_boot (
	port_t		cmd_port,	
	int		*bootImage,	
	int		bootImageSize,	
	int		priority);

/*
 * Set number of dma descriptors in stream.
 * New for 2.0.
 */
kern_return_t snddriver_stream_ndma (
	port_t		stream_port,	
	int		tag,		
	int		ndma);		

/* 
 * Reset dsp (new in 2.0). 
 */
kern_return_t snddriver_dsp_reset (
	port_t		cmd_port,	
	int		priority);	

/*
 * Re-allocate the device port.  This causes all current connections to be
 * terminated. (New in 2.0)
 * This routine causes the current device port (and all other driver ports) to be
 * deallocated.  A new device port is allocated and returned in the new_dev_port
 * argument.  The purpose of this call is to provide security by allowing a privileged
 * entity to terminate all connections to the device and re-register the device in the
 * proper name space.  The host_priv_port argument is the port returned by the
 * host_priv_port() trap (see <mach_host.h>).
 */
kern_return_t snddriver_new_device_port (
	port_t		device_port,
	port_t		host_priv_port,
	port_t		*new_dev_port);

/*
 * Exchange the current dsp owner port with a new one.  New for 2.0.
 */
kern_return_t snddriver_reset_dsp_owner (
	port_t		device_port,
	port_t		old_owner_port,
	port_t		new_owner_port,
	port_t		new_negotiation)

/*
 * Exchange the current sndin owner port with a new one.  New for 2.0.
 */
kern_return_t snddriver_reset_sndin_owner (
	port_t		device_port,
	port_t		old_owner_port,
	port_t		new_owner_port,
	port_t		new_negotiation)

/*
 * Exchange the current sndout owner port with a new one.  New for 2.0.
 */
kern_return_t snddriver_reset_sndout_owner (
	port_t		device_port,
	port_t		old_owner_port,
	port_t		new_owner_port,
	port_t		new_negotiation)

/*
 * User-initiated dma transfer to dsp. See programming examples. (New in 2.0.)
 */
kern_return_t snddriver_dsp_dma_write (
	port_t		cmd_port,
	int		size,	
	int		mode,	
	void		*data);	

/*
 * User-initiated dma from dsp. See programming examples. (New in 2.0.)
 */
kern_return_t snddriver_dsp_dma_read (
	port_t		cmd_port,
	int		size,	
	int		mode,	
	void		**data);

/*
 * Set the size of the sound out buffers used by snddriver_stream_setup() when
 * it configures the stream.  The default is vm_page_size.
 * New in 2.0.
 */
kern_return_t snddriver_set_sndout_bufsize (
	port_t		dev_port,	
	port_t		owner_port,	
	int		sobsize);	

/*
 * Set the number of sound out buffers used by snddriver_stream_setup() when
 * it configures the stream.  The default is 4.
 * New in 2.0.
 */
kern_return_t snddriver_set_sndout_bufcount (
	port_t		dev_port,	
	port_t		owner_port,	
	int		sobcount);	

kern_return_t snddriver_stream_setup (
	port_t		dev_port,	
	port_t		owner_port,	
	int		config,		
	int		buf_size,	
	int		sample_size,	
	int		low_water,	
	int		high_water,	
	int		*protocol,	
	port_t		*stream_port);

kern_return_t snddriver_dsp_protocol (
	port_t		device_port,	
	port_t		owner_port,	
	int		protocol);

/*
 * Stream interaction functions
 */
kern_return_t snddriver_stream_start_reading (
	port_t		stream_port,	
	char		*filename,	
	int		data_size,	
	int		tag,		
	boolean_t	started_msg,	
	boolean_t	completed_msg,	
	boolean_t	aborted_msg,	
	boolean_t	paused_msg,	
	boolean_t	resumed_msg,	
	boolean_t	overflow_msg,	
	port_t		reply_port);	

kern_return_t snddriver_stream_start_writing (
	port_t		stream_port,	
	void		*data,		
	int		data_size,	
	int		tag,		
	boolean_t	preempt,	
	boolean_t	deallocate,	
	boolean_t	started_msg,	
	boolean_t	completed_msg,	
	boolean_t	aborted_msg,	
	boolean_t	paused_msg,	
	boolean_t	resumed_msg,	
	boolean_t	overflow_msg,	
	port_t		reply_port);

kern_return_t snddriver_stream_control (
	port_t		stream_port,	
	int		tag,		
	int		snd_control);

kern_return_t snddriver_stream_nsamples (
	port_t		stream_port,	
	int		*nsamples);
